@@ -84,6 +84,8 @@ HFONT myfont; /* handle of font for screen */
 int winopened = FALSE;   /* flag if window is open already */
 char *winorigin;         /* e.g. "lt","rc"; defines origin of grafic window */
 int winwidth, winheight; /* size of window */
+int displaywidth = 0;     /* width of display */
+int displayheight = 0;    /* height of display */
 static int winx, winy;   /* position of window */
 
 /* mouse and keyboard */
@@ -110,7 +112,7 @@ char *displayname = NULL;
 char *fontname = NULL;
 #ifdef UNIX
 static unsigned long forepixel, backpixel; /* colors */
-Display *display;                          /* X-Display */
+Display *display = NULL;                   /* X-Display */
 static Window root;                        /* ID of root window */
 static Window window;                      /* ID of grafic window */
 static GC gc;                              /* GC for drawing */
@@ -262,7 +264,7 @@ void openwin(struct command *cmd) {
     prctl(PR_SET_PDEATHSIG, SIGHUP);
 #endif
     /* we (child-process) get our own display-connection, probably on purpose */
-    display = XOpenDisplay(displayname);
+    if (!display) display = XOpenDisplay(displayname);
     XSelectInput(display, window, ExposureMask);
     XGetGCValues(display, gc, GCPlaneMask, &vals);
     while (TRUE) {
@@ -2818,7 +2820,7 @@ void x11_send_expose() {
   }
   memset(&event, 0, sizeof(XExposeEvent));
   event.type = Expose;
-  display = XOpenDisplay(displayname);      
+  if (!display) display = XOpenDisplay(displayname);      
   event.display = display;
   event.window = window;
   event.x = 0;
@@ -2829,6 +2831,33 @@ void x11_send_expose() {
   XSync(display, 0);
   error(sNOTE, "Sent X11-event Expose to my own window");
 #else
-  error(sERROR, "'debug_internal' 'xee_send_expose' is not available under windows");
+  error(sERROR, "'debug_internal' 'x11_send_expose' is not available under windows");
 #endif      
 }
+
+
+void determine_display_size() {
+  /* determine size of display and store within global vars */
+  static int succeeded = FALSE;
+#ifdef UNIX
+  static int failed = FALSE;
+  int num;
+
+  if (succeeded) return;
+  if (failed) return;
+  if (!display) display = XOpenDisplay(displayname);
+  if (!display) {
+    failed = TRUE;
+    return;
+  }
+  num = DefaultScreen(display);
+  displaywidth = DisplayWidth(display, num);
+  displayheight = DisplayHeight(display, num);
+#else
+  if (succeeded) return;
+  /* if screen scaling is active (e.g. scaling factor of 150%), this returns 1280 instead of 1920 */
+  displaywidth = GetSystemMetrics(SM_CXSCREEN);
+  displayheight = GetSystemMetrics(SM_CYSCREEN);
+#endif
+  succeeded = TRUE;
+}
