@@ -176,6 +176,8 @@ extern double yinc;		/* inclination for y-mapping */
 extern int winopened;		/* flag if window is open already */
 extern char *winorigin;		/* e.g. "lt","rc"; defines origin of grafic window */
 extern int winwidth, winheight;	/* size of window */
+extern int displaywidth, displayheight;  /* size of display */
+extern void determine_display_size(); /* determine size of display and store within global vars */
 /* mouse, console and keyboard */
 extern int mousex, mousey, mouseb, mousemod;	/* last know mouse coordinates */
 extern char *ykey[];		/* keys returned by inkey */
